@@ -1,24 +1,10 @@
 /*
-   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "csvimportexportplugininterface.h"
-#include "../shared/importexportengine.h"
 #include "import/csvimportdialog.h"
 #include <KLocalizedString>
 #include <KActionCollection>
@@ -32,17 +18,17 @@
 #include <QFileDialog>
 #include <QTextCodec>
 #include <QPointer>
-#include <KAddressBookContactSelectionDialog>
 #include <KIO/Job>
 
+#include <KAddressBookImportExport/ContactSelectionDialog>
+#include <KAddressBookImportExport/ImportExportEngine>
+
 CSVImportExportPluginInterface::CSVImportExportPluginInterface(QObject *parent)
-    : KAddressBookImportExport::KAddressBookImportExportPluginInterface(parent)
+    : KAddressBookImportExport::PluginInterface(parent)
 {
 }
 
-CSVImportExportPluginInterface::~CSVImportExportPluginInterface()
-{
-}
+CSVImportExportPluginInterface::~CSVImportExportPluginInterface() = default;
 
 void CSVImportExportPluginInterface::createAction(KActionCollection *ac)
 {
@@ -73,14 +59,14 @@ void CSVImportExportPluginInterface::exec()
 
 void CSVImportExportPluginInterface::importCSV()
 {
-    KAddressBookImportExport::KAddressBookImportExportContactList contactList;
+    KAddressBookImportExport::ContactList contactList;
     QPointer<CSVImportDialog> dlg = new CSVImportDialog(parentWidget());
     if (dlg->exec()) {
         contactList.setAddressList(dlg->contacts());
     }
 
     delete dlg;
-    ImportExportEngine *engine = new ImportExportEngine(this);
+    auto *engine = new KAddressBookImportExport::ImportExportEngine(this);
     engine->setContactList(contactList);
     engine->setDefaultAddressBook(defaultCollection());
     engine->importContacts();
@@ -103,8 +89,8 @@ void CSVImportExportPluginInterface::exportToFile(QFile *file, const KContacts::
     QTextStream stream(file);
     stream.setCodec(QTextCodec::codecForLocale());
 
-    KAddressBookImportExport::KAddressBookImportExportContactFields::Fields fields = KAddressBookImportExport::KAddressBookImportExportContactFields::allFields();
-    fields.remove(KAddressBookImportExport::KAddressBookImportExportContactFields::Undefined);
+    auto fields = KAddressBookImportExport::ContactFields::allFields();
+    fields.remove(KAddressBookImportExport::ContactFields::Undefined);
 
     bool first = true;
 
@@ -116,7 +102,7 @@ void CSVImportExportPluginInterface::exportToFile(QFile *file, const KContacts::
         }
 
         // add quoting as defined in RFC 4180
-        QString label = KAddressBookImportExport::KAddressBookImportExportContactFields::label(fields.at(i));
+        QString label = KAddressBookImportExport::ContactFields::label(fields.at(i));
         label.replace(QLatin1Char('"'), QStringLiteral("\"\""));
 
         stream << "\"" << label << "\"";
@@ -135,15 +121,15 @@ void CSVImportExportPluginInterface::exportToFile(QFile *file, const KContacts::
             }
 
             QString content;
-            if (fields.at(j) == KAddressBookImportExport::KAddressBookImportExportContactFields::Birthday
-                || fields.at(j) == KAddressBookImportExport::KAddressBookImportExportContactFields::Anniversary) {
+            if (fields.at(j) == KAddressBookImportExport::ContactFields::Birthday
+                || fields.at(j) == KAddressBookImportExport::ContactFields::Anniversary) {
                 const QDateTime dateTime
-                    = QDateTime::fromString(KAddressBookImportExport::KAddressBookImportExportContactFields::value(fields.at(j), contact), Qt::ISODate);
+                    = QDateTime::fromString(KAddressBookImportExport::ContactFields::value(fields.at(j), contact), Qt::ISODate);
                 if (dateTime.isValid()) {
                     content = dateTime.date().toString(Qt::ISODate);
                 }
             } else {
-                content = KAddressBookImportExport::KAddressBookImportExportContactFields::value(fields.at(j), contact).replace(QLatin1Char('\n'), QStringLiteral("\\n"));
+                content = KAddressBookImportExport::ContactFields::value(fields.at(j), contact).replace(QLatin1Char('\n'), QStringLiteral("\\n"));
             }
 
             // add quoting as defined in RFC 4180
@@ -159,8 +145,8 @@ void CSVImportExportPluginInterface::exportToFile(QFile *file, const KContacts::
 
 void CSVImportExportPluginInterface::exportCSV()
 {
-    QPointer<KAddressBookImportExport::KAddressBookContactSelectionDialog> dlg
-        = new KAddressBookImportExport::KAddressBookContactSelectionDialog(itemSelectionModel(), false, parentWidget());
+    QPointer<KAddressBookImportExport::ContactSelectionDialog> dlg
+        = new KAddressBookImportExport::ContactSelectionDialog(itemSelectionModel(), false, parentWidget());
     dlg->setMessageText(i18n("Which contact do you want to export?"));
     dlg->setDefaultAddressBook(defaultCollection());
     if (!dlg->exec()) {
@@ -175,7 +161,7 @@ void CSVImportExportPluginInterface::exportCSV()
         return;
     }
 
-    KAddressBookImportExport::KAddressBookImportExportContactList contactLists;
+    KAddressBookImportExport::ContactList contactLists;
     contactLists.setAddressList(contacts);
     QFileDialog::Options options = QFileDialog::DontConfirmOverwrite;
     QUrl url = QFileDialog::getSaveFileUrl(parentWidget(), QString(), QUrl::fromLocalFile(QStringLiteral("addressbook.csv")), QString(), nullptr, options);
@@ -185,8 +171,8 @@ void CSVImportExportPluginInterface::exportCSV()
 
     if (QFileInfo::exists(url.isLocalFile() ? url.toLocalFile() : url.path())) {
         if (url.isLocalFile() && QFileInfo::exists(url.toLocalFile())) {
-            PimCommon::RenameFileDialog *dialog = new PimCommon::RenameFileDialog(url, false, parentWidget());
-            PimCommon::RenameFileDialog::RenameFileDialogResult result = static_cast<PimCommon::RenameFileDialog::RenameFileDialogResult>(dialog->exec());
+            auto *dialog = new PimCommon::RenameFileDialog(url, false, parentWidget());
+            auto result = static_cast<PimCommon::RenameFileDialog::RenameFileDialogResult>(dialog->exec());
             if (result == PimCommon::RenameFileDialog::RENAMEFILE_RENAME) {
                 url = dialog->newName();
             } else if (result == PimCommon::RenameFileDialog::RENAMEFILE_IGNORE) {
