@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "gravatarupdatedialog.h"
@@ -27,11 +14,13 @@
 #include <QPushButton>
 
 using namespace KABGravatar;
-
+namespace {
+static const char myConfigGroupName[] = "GravatarUpdateDialog";
+}
 GravatarUpdateDialog::GravatarUpdateDialog(QWidget *parent)
     : QDialog(parent)
 {
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     setWindowTitle(i18nc("@title:window", "Check and update Gravatar"));
     mGravatarUpdateWidget = new GravatarUpdateWidget(this);
     connect(mGravatarUpdateWidget, &GravatarUpdateWidget::activateDialogButton, this, &GravatarUpdateDialog::slotActivateButton);
@@ -109,7 +98,7 @@ void GravatarUpdateDialog::setOriginalPixmap(const QPixmap &pix)
 
 void GravatarUpdateDialog::readConfig()
 {
-    KConfigGroup grp(KSharedConfig::openConfig(), "GravatarUpdateDialog");
+    KConfigGroup grp(KSharedConfig::openConfig(), myConfigGroupName);
     const QSize size = grp.readEntry("Size", QSize(300, 200));
     if (size.isValid()) {
         resize(size);
@@ -118,7 +107,7 @@ void GravatarUpdateDialog::readConfig()
 
 void GravatarUpdateDialog::writeConfig()
 {
-    KConfigGroup grp(KSharedConfig::openConfig(), "GravatarUpdateDialog");
+    KConfigGroup grp(KSharedConfig::openConfig(), myConfigGroupName);
     grp.writeEntry("Size", size());
     grp.sync();
 }
