@@ -1,27 +1,14 @@
 /*
-   Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "searchduplicateresultwidgettest.h"
 #include "../searchduplicate/searchduplicateresultwidget.h"
 #include "../searchduplicate/resultduplicatetreewidget.h"
 #include "../widgets/mergecontactloseinformationwarning.h"
-#include <KaddressbookGrantlee/GrantleeContactViewer>
+#include <Akonadi/Contact/GrantleeContactViewer>
 #include <QSplitter>
 #include <QLayout>
 #include <QLabel>
@@ -34,7 +21,7 @@
 
 using namespace KContacts;
 namespace KABMergeContacts {
-KADDRESSBOOKMERGELIB_EXPORT QAbstractItemModel *_k_searchDuplicateResultStubModel = nullptr;
+QAbstractItemModel *_k_searchDuplicateResultStubModel = nullptr;
 }
 
 SearchDuplicateResultWidgetTest::SearchDuplicateResultWidgetTest(QObject *parent)
