@@ -1,20 +1,7 @@
 /*
-    Copyright (C) 2019-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "markdowncreateimagewidget.h"
@@ -27,9 +14,9 @@
 MarkdownCreateImageWidget::MarkdownCreateImageWidget(QWidget *parent)
     : QWidget(parent)
 {
-    QFormLayout *mainLayout = new QFormLayout(this);
+    auto *mainLayout = new QFormLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainlayout"));
-    mainLayout->setContentsMargins(0, 0, 0, 0);
+    mainLayout->setContentsMargins({});
 
     mTitle = new QLineEdit(this);
     mTitle->setObjectName(QStringLiteral("title"));
@@ -54,6 +41,13 @@ MarkdownCreateImageWidget::MarkdownCreateImageWidget(QWidget *parent)
     mainLayout->addRow(mKeepOriginalSize);
     connect(mKeepOriginalSize, &QCheckBox::stateChanged, this, &MarkdownCreateImageWidget::slotKeepOriginalSizeChanged);
 
+    QWidget *sizeWidget = new QWidget;
+    sizeWidget->setObjectName(QStringLiteral("sizeWidget"));
+    auto *sizeWidgetLayout = new QHBoxLayout(sizeWidget);
+    sizeWidgetLayout->setObjectName(QStringLiteral("sizeWidgetLayout"));
+    sizeWidgetLayout->setContentsMargins({});
+    mainLayout->addRow(sizeWidget);
+
     mLabWidth = new QLabel(i18n("Width:"), this);
     mLabWidth->setObjectName(QStringLiteral("labwidth"));
     mLabWidth->setEnabled(false);
@@ -64,7 +58,8 @@ MarkdownCreateImageWidget::MarkdownCreateImageWidget(QWidget *parent)
     mWidth->setValue(50);
     mWidth->setEnabled(false);
     mWidth->setSuffix(i18n(" px"));
-    mainLayout->addRow(mLabWidth, mWidth);
+    sizeWidgetLayout->addWidget(mLabWidth);
+    sizeWidgetLayout->addWidget(mWidth);
 
     mLabHeight = new QLabel(i18n("Height:"), this);
     mLabHeight->setObjectName(QStringLiteral("labheight"));
@@ -76,7 +71,9 @@ MarkdownCreateImageWidget::MarkdownCreateImageWidget(QWidget *parent)
     mHeight->setValue(50);
     mHeight->setEnabled(false);
     mHeight->setSuffix(i18n(" px"));
-    mainLayout->addRow(mLabHeight, mHeight);
+    sizeWidgetLayout->addWidget(mLabHeight);
+    sizeWidgetLayout->addWidget(mHeight);
+    sizeWidgetLayout->addStretch(1);
 }
 
 MarkdownCreateImageWidget::~MarkdownCreateImageWidget()
