@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "insertshorturlconfigurewidget.h"
@@ -27,13 +14,15 @@
 #include <QComboBox>
 #include <QLabel>
 #include <QVBoxLayout>
-
+namespace {
+static const char myConfigGroupName[] = "ShortUrl";
+}
 InsertShorturlConfigureWidget::InsertShorturlConfigureWidget(QWidget *parent)
     : QWidget(parent)
 {
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainlayout"));
-    mainLayout->setContentsMargins(0, 0, 0, 0);
+    mainLayout->setContentsMargins({});
 
     QLabel *lab = new QLabel(i18n("Select Short URL server:"), this);
     lab->setObjectName(QStringLiteral("label"));
@@ -62,7 +51,7 @@ void InsertShorturlConfigureWidget::slotChanged()
 
 void InsertShorturlConfigureWidget::loadConfig()
 {
-    KConfigGroup grp(KSharedConfig::openConfig(), "ShortUrl");
+    KConfigGroup grp(KSharedConfig::openConfig(), myConfigGroupName);
     const QString engineName = grp.readEntry("EngineName");
     int index = mShortUrlServer->findData(engineName);
     if (index < 0) {
@@ -75,7 +64,7 @@ void InsertShorturlConfigureWidget::loadConfig()
 void InsertShorturlConfigureWidget::writeConfig()
 {
     if (mChanged) {
-        KConfigGroup grp(KSharedConfig::openConfig(), "ShortUrl");
+        KConfigGroup grp(KSharedConfig::openConfig(), myConfigGroupName);
         grp.writeEntry("EngineName", mShortUrlServer->itemData(mShortUrlServer->currentIndex()).toString());
         grp.sync();
     }
