@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "automaticaddcontactsjob.h"
@@ -62,7 +49,7 @@ void AutomaticAddContactsJob::start()
 
 void AutomaticAddContactsJob::fetchCollection()
 {
-    Akonadi::CollectionFetchJob *const addressBookJob = new Akonadi::CollectionFetchJob(mCollection, Akonadi::CollectionFetchJob::Base);
+    auto *const addressBookJob = new Akonadi::CollectionFetchJob(mCollection, Akonadi::CollectionFetchJob::Base);
 
     const QStringList mimeTypes(KContacts::Addressee::mimeType());
     addressBookJob->fetchScope().setContentMimeTypes(mimeTypes);
@@ -125,7 +112,7 @@ void AutomaticAddContactsJob::slotFetchAllCollections(KJob *job)
                 const Akonadi::AgentType agentType = dlg->agentType();
 
                 if (agentType.isValid()) {
-                    Akonadi::AgentInstanceCreateJob *job = new Akonadi::AgentInstanceCreateJob(agentType, this);
+                    auto *job = new Akonadi::AgentInstanceCreateJob(agentType, this);
                     connect(job, &KJob::result, this, &AutomaticAddContactsJob::slotResourceCreationDone);
                     job->configure();
                     job->start();
@@ -197,7 +184,7 @@ void AutomaticAddContactsJob::verifyContactExist()
             mProcessEmail = email;
             mName = tname;
             mProcessedEmails.append(email);
-            Akonadi::ContactSearchJob *searchJob = new Akonadi::ContactSearchJob(this);
+            auto *searchJob = new Akonadi::ContactSearchJob(this);
             searchJob->setLimit(1);
             searchJob->setQuery(Akonadi::ContactSearchJob::Email, mProcessEmail.toLower(),
                                 Akonadi::ContactSearchJob::ExactMatch);
@@ -208,7 +195,7 @@ void AutomaticAddContactsJob::verifyContactExist()
 
 void AutomaticAddContactsJob::slotSearchDone(KJob *job)
 {
-    Akonadi::ContactSearchJob *searchJob = static_cast<Akonadi::ContactSearchJob *>(job);
+    auto *searchJob = static_cast<Akonadi::ContactSearchJob *>(job);
     if (searchJob->error()) {
         qCWarning(KMAIL_EDITOR_AUTOMATICADDCONTACTS_PLUGIN_LOG) << "Unable to fetch contact:" << searchJob->errorText();
     } else if (searchJob->contacts().isEmpty()) {
@@ -222,7 +209,7 @@ void AutomaticAddContactsJob::slotSearchDone(KJob *job)
         item.setPayload<KContacts::Addressee>(contact);
 
         // save the new item in akonadi storage
-        Akonadi::ItemCreateJob *createJob = new Akonadi::ItemCreateJob(item, mCollection, this);
+        auto *createJob = new Akonadi::ItemCreateJob(item, mCollection, this);
         connect(createJob, &KJob::result, this, &AutomaticAddContactsJob::slotAddContactDone);
         return;
     }
