@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "confirmaddressinterface.h"
@@ -30,7 +17,9 @@
 #include <KIdentityManagement/Identity>
 #include <MessageComposer/AliasesExpandJob>
 #include <PimCommon/PimUtil>
-
+namespace {
+static const char myConfigGroupName[] = "Confirm Address";
+}
 ConfirmAddressInterface::ConfirmAddressInterface(QObject *parent)
     : MessageComposer::PluginEditorCheckBeforeSendInterface(parent)
 {
@@ -95,7 +84,7 @@ bool ConfirmAddressInterface::exec(const MessageComposer::PluginEditorCheckBefor
 
 void ConfirmAddressInterface::slotAddWhiteListEmails(const QStringList &lst, uint currentIdentity)
 {
-    KConfigGroup grp(KSharedConfig::openConfig(), "Confirm Address");
+    KConfigGroup grp(KSharedConfig::openConfig(), myConfigGroupName);
     KConfigGroup identityGroup = grp.group(QStringLiteral("Confirm Address %1").arg(currentIdentity));
     QStringList oldWhiteList = identityGroup.readEntry("Emails", QStringList());
     for (const QString &email : lst) {
@@ -110,7 +99,7 @@ void ConfirmAddressInterface::slotAddWhiteListEmails(const QStringList &lst, uin
 
 void ConfirmAddressInterface::reloadConfig()
 {
-    KConfigGroup grp(KSharedConfig::openConfig(), "Confirm Address");
+    KConfigGroup grp(KSharedConfig::openConfig(), myConfigGroupName);
     mHashSettings.clear();
 
     KIdentityManagement::IdentityManager *im = KIdentityManagement::IdentityManager::self();
