@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "grammalecteconfigwidget.h"
@@ -38,11 +25,11 @@ GrammalecteConfigWidget::GrammalecteConfigWidget(QWidget *parent, bool disableMe
     : QWidget(parent)
     , mDisableDialogBox(disableMessageBox)
 {
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainlayout"));
-    mainLayout->setContentsMargins(0, 0, 0, 0);
+    mainLayout->setContentsMargins({});
 
-    QTabWidget *mTab = new QTabWidget(this);
+    auto *mTab = new QTabWidget(this);
     mTab->setObjectName(QStringLiteral("mTab"));
     mainLayout->addWidget(mTab);
     mTab->addTab(addGeneralTab(), i18n("General"));
@@ -58,7 +45,7 @@ GrammalecteConfigWidget::~GrammalecteConfigWidget()
 
 void GrammalecteConfigWidget::loadGrammarSettings()
 {
-    GrammalecteGenerateConfigOptionJob *job = new GrammalecteGenerateConfigOptionJob(this);
+    auto *job = new GrammalecteGenerateConfigOptionJob(this);
     job->setPythonPath(mPythonPath->text());
     job->setGrammarlecteCliPath(mGrammalectePath->text());
     connect(job, &GrammalecteGenerateConfigOptionJob::finished, this, &GrammalecteConfigWidget::slotGetSettingsFinished);
@@ -80,11 +67,11 @@ void GrammalecteConfigWidget::slotGetSettingsFinished(const QVector<GrammalecteG
     mListOptions.clear();
     mListOptions.reserve(result.count());
     delete mGrammarTabWidget->layout();
-    QVBoxLayout *layout = new QVBoxLayout(mGrammarTabWidget);
+    auto *layout = new QVBoxLayout(mGrammarTabWidget);
     layout->setObjectName(QStringLiteral("grammartablayout"));
 
     for (const GrammalecteGenerateConfigOptionJob::Option &opt : result) {
-        QCheckBox *box = new QCheckBox(opt.description, this);
+        auto *box = new QCheckBox(opt.description, this);
         box->setProperty("optionname", opt.optionName);
         if (mSaveOptions.isEmpty()) {
             box->setChecked(opt.defaultValue);
@@ -106,7 +93,7 @@ QWidget *GrammalecteConfigWidget::addGrammarTab()
     mScrollArea->setWidgetResizable(true);
     mGrammarTabWidget = new QWidget;
     mGrammarTabWidget->setObjectName(QStringLiteral("grammar"));
-    QVBoxLayout *layout = new QVBoxLayout(mGrammarTabWidget);
+    auto *layout = new QVBoxLayout(mGrammarTabWidget);
     layout->setObjectName(QStringLiteral("grammartablayout"));
     mScrollArea->setWidget(mGrammarTabWidget);
 
@@ -115,15 +102,15 @@ QWidget *GrammalecteConfigWidget::addGrammarTab()
     mReloadSettingsWidget = new QWidget;
     mReloadSettingsWidget->setObjectName(QStringLiteral("reloadwidget"));
     mStackedWidget->addWidget(mReloadSettingsWidget);
-    QVBoxLayout *reloadSettingsLayout = new QVBoxLayout(mReloadSettingsWidget);
+    auto *reloadSettingsLayout = new QVBoxLayout(mReloadSettingsWidget);
     reloadSettingsLayout->setObjectName(QStringLiteral("reloadSettingsLayout"));
-    QHBoxLayout *horizontallayout = new QHBoxLayout;
+    auto *horizontallayout = new QHBoxLayout;
     reloadSettingsLayout->addLayout(horizontallayout);
     QLabel *label = new QLabel(i18n("Press Button for Reloading Settings"), this);
     label->setObjectName(QStringLiteral("label"));
     horizontallayout->addWidget(label);
 
-    QToolButton *buttonReloadSettings = new QToolButton(this);
+    auto *buttonReloadSettings = new QToolButton(this);
     buttonReloadSettings->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
     buttonReloadSettings->setObjectName(QStringLiteral("buttonReloadSettings"));
     buttonReloadSettings->setToolTip(i18n("Reload Settings"));
@@ -138,7 +125,7 @@ QWidget *GrammalecteConfigWidget::addGeneralTab()
 {
     QWidget *w = new QWidget(this);
     w->setObjectName(QStringLiteral("general"));
-    QFormLayout *lay = new QFormLayout(w);
+    auto *lay = new QFormLayout(w);
     lay->setObjectName(QStringLiteral("generallayout"));
 
     mPythonPath = new KUrlRequester(this);
