@@ -1,27 +1,16 @@
 /*
-   Copyright (C) 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "grammalectemanager.h"
 #include <KConfigGroup>
 #include <KSharedConfig>
 #include <QStandardPaths>
-
+namespace {
+static const char myConfigGroupName[] = "Grammalecte";
+}
 GrammalecteManager::GrammalecteManager(QObject *parent)
     : QObject(parent)
 {
@@ -40,7 +29,7 @@ GrammalecteManager *GrammalecteManager::self()
 
 void GrammalecteManager::saveSettings()
 {
-    KConfigGroup grp(KSharedConfig::openConfig(), "Grammalecte");
+    KConfigGroup grp(KSharedConfig::openConfig(), myConfigGroupName);
     grp.writeEntry(QStringLiteral("pythonpath"), mPythonPath);
     grp.writeEntry(QStringLiteral("grammalectepath"), mGrammalectePath);
     grp.writeEntry(QStringLiteral("options"), mOptions);
@@ -58,7 +47,7 @@ void GrammalecteManager::setOptions(const QStringList &saveOptions)
 
 void GrammalecteManager::loadSettings()
 {
-    KConfigGroup grp(KSharedConfig::openConfig(), "Grammalecte");
+    KConfigGroup grp(KSharedConfig::openConfig(), myConfigGroupName);
     mPythonPath = grp.readEntry(QStringLiteral("pythonpath"));
     if (mPythonPath.isEmpty()) {
         mPythonPath = QStandardPaths::findExecutable(QStringLiteral("python3"));
