@@ -1,36 +1,12 @@
 /*
     This file is part of KMail.
-    Copyright (c) 2003 Andreas Gungl <a.gungl@gmx.de>
+    SPDX-FileCopyrightText: 2003 Andreas Gungl <a.gungl@gmx.de>
 
-    KMail is free software; you can redistribute it and/or modify it
-    under the terms of the GNU General Public License, version 2, as
-    published by the Free Software Foundation.
-
-    KMail is distributed in the hope that it will be useful, but
-    WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "antispamwizard.h"
-#ifndef QT_NO_CURSOR
-#include <Libkdepim/KCursorSaver>
-#endif
+#include <KCursorSaver>
 #include <MailCommon/FolderRequester>
 #include <MailCommon/FolderTreeWidget>
 #include <MailCommon/FolderTreeView>
@@ -64,6 +40,8 @@
 #include <QPushButton>
 #include <KConfigGroup>
 #include <QVector>
+#include <QEventLoop>
+#include <QApplication>
 #include <MailCommon/ResourceReadConfigFile>
 using namespace KMail;
 using namespace MailCommon;
@@ -169,7 +147,7 @@ void AntiSpamWizard::accept()
                 // pipe messages through the anti-virus tools,
                 // one single filter for each tool
                 // (could get combined but so it's easier to understand for the user)
-                MailFilter *pipeFilter = new MailFilter();
+                auto *pipeFilter = new MailFilter();
                 QVector<FilterAction *> *pipeFilterActions = pipeFilter->actions();
                 FilterAction *pipeFilterAction = dict.value(QStringLiteral("filter app"))->create();
                 pipeFilterAction->argsFromString((*it).getDetectCmd());
@@ -190,7 +168,7 @@ void AntiSpamWizard::accept()
 
         if (mVirusRulesPage->moveRulesSelected()) {
             // Sort out viruses depending on header fields set by the tools
-            MailFilter *virusFilter = new MailFilter();
+            auto *virusFilter = new MailFilter();
             QVector<FilterAction *> *virusFilterActions = virusFilter->actions();
             FilterAction *virusFilterAction1 = dict.value(QStringLiteral("transfer"))->create();
             virusFilterAction1->argsFromString(mVirusRulesPage->selectedFolderName());
@@ -247,7 +225,7 @@ void AntiSpamWizard::accept()
                 // pipe messages through the anti-spam tools,
                 // one single filter for each tool
                 // (could get combined but so it's easier to understand for the user)
-                MailFilter *pipeFilter = new MailFilter();
+                auto *pipeFilter = new MailFilter();
                 QVector<FilterAction *> *pipeFilterActions = pipeFilter->actions();
                 FilterAction *pipeFilterAction = dict.value(QStringLiteral("filter app"))->create();
                 pipeFilterAction->argsFromString((*it).getDetectCmd());
@@ -271,7 +249,7 @@ void AntiSpamWizard::accept()
         }
 
         // Sort out spam depending on header fields set by the tools
-        MailFilter *spamFilter = new MailFilter();
+        auto *spamFilter = new MailFilter();
         QVector<FilterAction *> *spamFilterActions = spamFilter->actions();
         if (mSpamRulesPage->moveSpamSelected()) {
             FilterAction *spamFilterAction1 = dict.value(QStringLiteral("transfer"))->create();
@@ -322,7 +300,7 @@ void AntiSpamWizard::accept()
         if (mSpamRulesPage->moveUnsureSelected()) {
             // Sort out messages classified as unsure
             bool atLeastOneUnsurePattern = false;
-            MailFilter *unsureFilter = new MailFilter();
+            auto *unsureFilter = new MailFilter();
             QVector<FilterAction *> *unsureFilterActions = unsureFilter->actions();
             FilterAction *unsureFilterAction1 = dict.value(QStringLiteral("transfer"))->create();
             unsureFilterAction1->argsFromString(mSpamRulesPage->selectedUnsureCollectionId());
@@ -368,7 +346,7 @@ void AntiSpamWizard::accept()
         }
 
         // Classify messages manually as Spam
-        MailFilter *classSpamFilter = new MailFilter();
+        auto *classSpamFilter = new MailFilter();
         classSpamFilter->setIcon(QStringLiteral("mail-mark-junk"));
         QVector<FilterAction *> *classSpamFilterActions = classSpamFilter->actions();
         FilterAction *classSpamFilterActionFirst = dict.value(QStringLiteral("set status"))->create();
@@ -408,7 +386,7 @@ void AntiSpamWizard::accept()
         filterList.append(classSpamFilter);
 
         // Classify messages manually as not Spam / as Ham
-        MailFilter *classHamFilter = new MailFilter();
+        auto *classHamFilter = new MailFilter();
         classHamFilter->setIcon(QStringLiteral("mail-mark-notjunk"));
         QVector<FilterAction *> *classHamFilterActions = classHamFilter->actions();
         FilterAction *classHamFilterActionFirst = dict.value(QStringLiteral("set status"))->create();
@@ -511,9 +489,7 @@ void AntiSpamWizard::checkVirusRulesSelections()
 void AntiSpamWizard::checkToolAvailability()
 {
     // this can take some time to find the tools
-#ifndef QT_NO_CURSOR
-    KPIM::KCursorSaver busy(KPIM::KBusyPtr::busy());
-#endif
+    KCursorSaver saver(Qt::WaitCursor);
     bool found = false;
     QVector<SpamToolConfig>::ConstIterator end(mToolList.constEnd());
     for (QVector<SpamToolConfig>::ConstIterator it = mToolList.constBegin();
@@ -990,7 +966,7 @@ ASWizPage::ASWizPage(QWidget *parent, const QString &name)
     setObjectName(name);
     mLayout = new QHBoxLayout(this);
 
-    QVBoxLayout *sideLayout = new QVBoxLayout();
+    auto *sideLayout = new QVBoxLayout();
     mLayout->addItem(sideLayout);
     mLayout->addItem(new QSpacerItem(5, 5, QSizePolicy::Minimum, QSizePolicy::Expanding));
 
@@ -1014,7 +990,7 @@ ASWizInfoPage::ASWizInfoPage(AntiSpamWizard::WizardMode mode, QWidget *parent, c
     QBoxLayout *layout = new QVBoxLayout();
     mLayout->addItem(layout);
 
-    QTextEdit *introText = new QTextEdit(this);
+    auto *introText = new QTextEdit(this);
     introText->setText(
         (mode == AntiSpamWizard::AntiSpam)
         ? i18n(
@@ -1094,7 +1070,7 @@ void ASWizInfoPage::processSelectionChange()
 ASWizSpamRulesPage::ASWizSpamRulesPage(QWidget *parent, const QString &name)
     : ASWizPage(parent, name)
 {
-    QVBoxLayout *layout = new QVBoxLayout();
+    auto *layout = new QVBoxLayout();
     mLayout->addItem(layout);
 
     mMarkRules = new QCheckBox(i18n("&Mark detected spam messages as read"), this);
@@ -1113,7 +1089,7 @@ ASWizSpamRulesPage::ASWizSpamRulesPage(QWidget *parent, const QString &name)
     mFolderReqForSpamFolder->setMustBeReadWrite(true);
     mFolderReqForSpamFolder->setShowOutbox(false);
 
-    QHBoxLayout *hLayout1 = new QHBoxLayout();
+    auto *hLayout1 = new QHBoxLayout();
     layout->addItem(hLayout1);
     hLayout1->addWidget(mFolderReqForSpamFolder);
 
@@ -1130,7 +1106,7 @@ ASWizSpamRulesPage::ASWizSpamRulesPage(QWidget *parent, const QString &name)
     mFolderReqForUnsureFolder->setMustBeReadWrite(true);
     mFolderReqForUnsureFolder->setShowOutbox(false);
 
-    QHBoxLayout *hLayout2 = new QHBoxLayout();
+    auto *hLayout2 = new QHBoxLayout();
     layout->addItem(hLayout2);
     hLayout2->addWidget(mFolderReqForUnsureFolder);
 
@@ -1231,7 +1207,7 @@ void ASWizSpamRulesPage::allowMoveSpam(bool enabled)
 ASWizVirusRulesPage::ASWizVirusRulesPage(QWidget *parent, const QString &name)
     : ASWizPage(parent, name)
 {
-    QGridLayout *grid = new QGridLayout();
+    auto *grid = new QGridLayout();
     mLayout->addItem(grid);
 
     mPipeRules = new QCheckBox(i18n("Check messages using the anti-virus tools"), this);
