@@ -1,22 +1,10 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (c) 2007 Loïc Corbasson <loic.corbasson@gmail.com>
+  SPDX-FileCopyrightText: 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2007 Loïc Corbasson <loic.corbasson@gmail.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef KORG_PLUGINS_DATENUMS_DATENUMS_H
 #define KORG_PLUGINS_DATENUMS_DATENUMS_H
@@ -44,7 +32,7 @@ public:
     };
     Q_DECLARE_FLAGS(DayNumbers, DayNumber)
 
-    QString info() const override;
+    Q_REQUIRED_RESULT QString info() const override;
 
 private:
     DayNumbers mDisplayedInfo;
