@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "delegateselectortest.h"
@@ -38,20 +25,20 @@ DelegateSelectorTest::~DelegateSelectorTest()
 void DelegateSelectorTest::shouldHaveDefaultValue()
 {
     DelegateSelector w;
-    QLabel *label = w.findChild<QLabel *>(QStringLiteral("label"));
+    auto *label = w.findChild<QLabel *>(QStringLiteral("label"));
     QVERIFY(label);
     QVERIFY(!label->text().isEmpty());
 
-    PimCommon::AddresseeLineEdit *mDelegate = w.findChild<PimCommon::AddresseeLineEdit *>(QStringLiteral("delegate"));
+    auto *mDelegate = w.findChild<PimCommon::AddresseeLineEdit *>(QStringLiteral("delegate"));
     QVERIFY(mDelegate);
     QVERIFY(mDelegate->text().isEmpty());
 
-    QCheckBox *mRsvp = w.findChild<QCheckBox *>(QStringLiteral("informcheckbox"));
+    auto *mRsvp = w.findChild<QCheckBox *>(QStringLiteral("informcheckbox"));
     QVERIFY(mRsvp);
     QVERIFY(mRsvp->isChecked());
     QVERIFY(!mRsvp->text().isEmpty());
 
-    QDialogButtonBox *buttonBox = w.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
+    auto *buttonBox = w.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
     QVERIFY(buttonBox);
 
     QPushButton *mOkButton = buttonBox->button(QDialogButtonBox::Ok);
@@ -62,11 +49,11 @@ void DelegateSelectorTest::shouldHaveDefaultValue()
 void DelegateSelectorTest::shouldChangeOkButtonState()
 {
     DelegateSelector w;
-    PimCommon::AddresseeLineEdit *mDelegate = w.findChild<PimCommon::AddresseeLineEdit *>(QStringLiteral("delegate"));
+    auto *mDelegate = w.findChild<PimCommon::AddresseeLineEdit *>(QStringLiteral("delegate"));
     mDelegate->setEnableAkonadiSearch(false);
     mDelegate->setEnableBalooSearch(false);
 
-    QDialogButtonBox *buttonBox = w.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
+    auto *buttonBox = w.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
     QPushButton *mOkButton = buttonBox->button(QDialogButtonBox::Ok);
     QVERIFY(!mOkButton->isEnabled());
 
@@ -82,7 +69,7 @@ void DelegateSelectorTest::shouldChangeOkButtonState()
 void DelegateSelectorTest::shouldReturnCheckBoxState()
 {
     DelegateSelector w;
-    QCheckBox *mRsvp = w.findChild<QCheckBox *>(QStringLiteral("informcheckbox"));
+    auto *mRsvp = w.findChild<QCheckBox *>(QStringLiteral("informcheckbox"));
     QVERIFY(mRsvp->isChecked());
     mRsvp->setChecked(true);
     QVERIFY(w.rsvp());
