@@ -1,30 +1,7 @@
 /*
-    Copyright (c) 2010 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2010 Volker Krause <vkrause@kde.org>
 
-    This program is free software; you can redistribute it and/or modify it
-    under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful, but
-    WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "ms_tnef_debug.h"
@@ -97,13 +74,13 @@ public:
             f.close();
         }
         if (!buf.isEmpty()) {
-            KCalendarCore::MemoryCalendar::Ptr cl(
+            const KCalendarCore::MemoryCalendar::Ptr cl(
                 new KCalendarCore::MemoryCalendar(QTimeZone::systemTimeZone()));
             KCalUtils::InvitationFormatterHelper helper;
             const QString invite = KTnef::formatTNEFInvitation(buf, cl, &helper);
             KCalendarCore::ICalFormat format;
-            KCalendarCore::Incidence::Ptr inc = format.fromString(invite);
-            KCalendarCore::Event::Ptr event = inc.dynamicCast<KCalendarCore::Event>();
+            const KCalendarCore::Incidence::Ptr inc = format.fromString(invite);
+            const KCalendarCore::Event::Ptr event = inc.dynamicCast<KCalendarCore::Event>();
             if (event && event->hasEndDate()) {
                 // no enddate => not a valid invitation
                 inviteStr = KCalUtils::IncidenceFormatter::extensiveDisplayStr(cl, inc);
