@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "viewerplugincreatenotetest.h"
@@ -32,7 +19,7 @@ extern MESSAGEVIEWER_EXPORT QAbstractItemModel *_k_noteEditStubModel;
 ViewerPluginCreateNoteTest::ViewerPluginCreateNoteTest(QObject *parent)
     : QObject(parent)
 {
-    QStandardItemModel *model = new QStandardItemModel;
+    auto *model = new QStandardItemModel;
     MessageViewer::_k_noteEditStubModel = model;
 }
 
@@ -58,7 +45,7 @@ void ViewerPluginCreateNoteTest::shouldShowWidget()
     parent->setLayout(new QHBoxLayout);
     MessageViewer::ViewerPluginInterface *interface = note->createView(parent, new KActionCollection(this));
     interface->execute();
-    QWidget *createnotewidget = parent->findChild<QWidget *>(QStringLiteral("noteedit"));
+    auto *createnotewidget = parent->findChild<QWidget *>(QStringLiteral("noteedit"));
     QVERIFY(createnotewidget);
     QCOMPARE(createnotewidget->isHidden(), false);
 }
