@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "viewerpluginexternaleditwidgettest.h"
@@ -36,17 +23,17 @@ ViewerPluginExternalEditWidgetTest::~ViewerPluginExternalEditWidgetTest()
 void ViewerPluginExternalEditWidgetTest::shouldHaveDefaultValue()
 {
     ViewerPluginExternalEditWidget w;
-    QFormLayout *mainLayout = w.findChild<QFormLayout *>(QStringLiteral("mainlayout"));
+    auto *mainLayout = w.findChild<QFormLayout *>(QStringLiteral("mainlayout"));
     QVERIFY(mainLayout);
     QCOMPARE(mainLayout->contentsMargins(), QMargins(0, 0, 0, 0));
 
-    QLineEdit *mName = w.findChild<QLineEdit *>(QStringLiteral("name"));
+    auto *mName = w.findChild<QLineEdit *>(QStringLiteral("name"));
     QVERIFY(mName);
 
-    QLineEdit *mDescription = w.findChild<QLineEdit *>(QStringLiteral("description"));
+    auto *mDescription = w.findChild<QLineEdit *>(QStringLiteral("description"));
     QVERIFY(mDescription);
 
-    QLineEdit *mCommandLine = w.findChild<QLineEdit *>(QStringLiteral("commandline"));
+    auto *mCommandLine = w.findChild<QLineEdit *>(QStringLiteral("commandline"));
     QVERIFY(mCommandLine);
 
     auto mExecutable = w.findChild<KUrlRequester *>(QStringLiteral("mEditorRequester"));
